@@ -146,19 +146,6 @@ print_state(Sink) ->
 print_bad_state(Sink) ->
     gen_event:call(Sink, ?MODULE, print_bad_state).
 
-
-has_line_numbers() ->
-    %% are we R15 or greater
-    % this gets called a LOT - cache the answer
-    case erlang:get({?MODULE, has_line_numbers}) of
-        undefined ->
-            R = lager_util:otp_version() >= 15,
-            erlang:put({?MODULE, has_line_numbers}, R),
-            R;
-        Bool ->
-            Bool
-    end.
-
 not_running_test() ->
     ?assertEqual({error, lager_not_running}, lager:log(info, self(), "not running")).
 
@@ -188,6 +175,16 @@ lager_test_() ->
                         ok
                 end
             },
+            {"logging with macro works",
+                fun() ->
+                        ?lager_warning("test message", []),
+                        ?assertEqual(1, count()),
+                        {Level, _Time, Message, _Metadata}  = pop(),
+                        ?assertMatch(Level, lager_util:level_to_num(warning)),
+                        ?assertEqual("test message", Message),
+                        ok
+                end
+            },
             {"unsafe logging works",
                 fun() ->
                         lager:warning_unsafe("test message"),
@@ -208,6 +205,16 @@ lager_test_() ->
                         ok
                 end
             },
+            {"logging with macro and arguments works",
+                fun() ->
+                        ?lager_warning("test message ~p", [self()]),
+                        ?assertEqual(1, count()),
+                        {Level, _Time, Message,_Metadata}  = pop(),
+                        ?assertMatch(Level, lager_util:level_to_num(warning)),
+                        ?assertEqual(lists:flatten(io_lib:format("test message ~p", [self()])), lists:flatten(Message)),
+                        ok
+                end
+            },
             {"unsafe logging with args works",
                 fun() ->
                         lager:warning_unsafe("test message ~p", [self()]),
@@ -881,45 +888,40 @@ crash(Type) ->
     ok.
 
 test_body(Expected, Actual) ->
-    case has_line_numbers() of
+    ExLen = length(Expected),
+    {Body, Rest} = case length(Actual) > ExLen of
         true ->
-            ExLen = length(Expected),
-            {Body, Rest} = case length(Actual) > ExLen of
-                true ->
-                    {string:substr(Actual, 1, ExLen),
-                        string:substr(Actual, (ExLen + 1))};
-                _ ->
-                    {Actual, []}
-            end,
-            ?assertEqual(Expected, Body),
-            % OTP-17 (and maybe later releases) may tack on additional info
-            % about the failure, so if Actual starts with Expected (already
-            % confirmed by having gotten past assertEqual above) and ends
-            % with " line NNN" we can ignore what's in-between. By extension,
-            % since there may not be line information appended at all, any
-            % text we DO find is reportable, but not a test failure.
-            case Rest of
-                [] ->
-                    ok;
-                _ ->
-                    % isolate the extra data and report it if it's not just
-                    % a line number indicator
-                    case re:run(Rest, "^.*( line \\d+)$", [{capture, [1]}]) of
-                        nomatch ->
-                            ?debugFmt(
-                                "Trailing data \"~s\" following \"~s\"",
-                                [Rest, Expected]);
-                        {match, [{0, _}]} ->
-                            % the whole sting is " line NNN"
-                            ok;
-                        {match, [{Off, _}]} ->
-                            ?debugFmt(
-                                "Trailing data \"~s\" following \"~s\"",
-                                [string:substr(Rest, 1, Off), Expected])
-                    end
-            end;
+            {string:substr(Actual, 1, ExLen),
+                string:substr(Actual, (ExLen + 1))};
         _ ->
-            ?assertEqual(Expected, Actual)
+            {Actual, []}
+    end,
+    ?assertEqual(Expected, Body),
+    % OTP-17 (and maybe later releases) may tack on additional info
+    % about the failure, so if Actual starts with Expected (already
+    % confirmed by having gotten past assertEqual above) and ends
+    % with " line NNN" we can ignore what's in-between. By extension,
+    % since there may not be line information appended at all, any
+    % text we DO find is reportable, but not a test failure.
+    case Rest of
+        [] ->
+            ok;
+        _ ->
+            % isolate the extra data and report it if it's not just
+            % a line number indicator
+            case re:run(Rest, "^.*( line \\d+)$", [{capture, [1]}]) of
+                nomatch ->
+                    ?debugFmt(
+                       "Trailing data \"~s\" following \"~s\"",
+                       [Rest, Expected]);
+                {match, [{0, _}]} ->
+                    % the whole sting is " line NNN"
+                    ok;
+                {match, [{Off, _}]} ->
+                    ?debugFmt(
+                       "Trailing data \"~s\" following \"~s\"",
+                       [string:substr(Rest, 1, Off), Expected])
+            end
     end.
 
 error_logger_redirect_crash_setup() ->
@@ -1087,6 +1089,7 @@ error_logger_redirect_crash_test_() ->
         TestBody("bad arg2",badarg2,"gen_server crash terminated with reason: bad argument in call to erlang:iolist_to_binary([\"foo\",bar]) in crash:handle_call/3"),
         TestBody("bad record",badrecord,"gen_server crash terminated with reason: bad record state in crash:handle_call/3"),
         TestBody("noproc",noproc,"gen_server crash terminated with reason: no such process or port in call to gen_event:call(foo, bar, baz)"),
+        TestBody("noproc_proc_lib",noproc_proc_lib,"gen_server crash terminated with reason: no such process or port in call to proc_lib:stop/3"),
         TestBody("badfun",badfun,"gen_server crash terminated with reason: bad function booger in crash:handle_call/3")
     ],
     {"Error logger redirect crash", [
